@@ -5,5 +5,7 @@ from .stats import quality, IV, VIF, WOE
 from .selection import select
 from .transform import Combiner
 from .metrics import KS, F1, PSI
-from .scorecard import ScoreCard
+from .plot import bin_plot,score_plot
+from .model import Model
+from .performance import performance
 
